@@ -1,6 +1,6 @@
 package App::denomfind ;  
-our $VERSION = '0.303' ; 
-our $DATE = '2022-10-20T14:14+09:00' ; 
+our $VERSION = '0.312' ; 
+our $DATE = '2022-10-21T23:01+09:00' ; 
 
 =encoding utf8
 
@@ -10,6 +10,8 @@ App::denomfind -- Finding the common denominator for multiple approximated quoti
 
    1. denomfind -- 複数の四捨五入などされた数値を、共通した1個の分母を持つ整数比と見なして、その分母を総当たりで探索する。
    2. primefind -- 1行ずつ整数を逐次読み取り、ある数が既に読んだどの数の倍数でなければ、出力する。
+   3. color0    -- 入力(標準入力またはファイル)を読み取り、ASCIIエスケープシーケンにスよる色を除去する。
+   4. transpose -- TSV形式の入力を、縦横を入れ替える。行列の転置の演算と同じ事をする。
 
 =head1 SYNOPSIS
 
